@@ -6,10 +6,10 @@ from .custom_scalar import scalar  # noqa
 from .directive import directive  # noqa
 from .enum import enum  # noqa
 from .field import field  # noqa
+from .lazy_type import LazyType  # noqa
 from .mutation import mutation, subscription  # noqa
 from .permission import BasePermission  # noqa
 from .scalars import ID  # noqa
 from .schema import Schema  # noqa
 from .type import input, interface, type  # noqa
-from .types import *  # noqa
 from .union import union  # noqa
