@@ -28,12 +28,9 @@ class StrawberryField(dataclasses.Field):
         """Migrate the field definition to the resolver"""
 
         field_definition = self._field_definition
-        # Note: field_definition.name is finalized in type_resolver._get_fields
-
-        resolver_name = to_camel_case(resolver.__name__)
-
-        field_definition.origin_name = resolver_name
+        # note that field_definition.name is finalized in type_resolver._get_fields
 
+        field_definition.origin_name = resolver.__name__
         field_definition.origin = resolver
         field_definition.base_resolver = resolver
         field_definition.arguments = get_arguments_from_resolver(resolver)
