@@ -1,12 +1,20 @@
+import dataclasses
 from abc import abstractmethod
-from typing import Any, Dict, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 
+from graphql.error.graphql_error import GraphQLError
 from strawberry.custom_scalar import ScalarDefinition
 from strawberry.enum import EnumDefinition
 from strawberry.types.types import TypeDefinition
 from typing_extensions import Protocol
 
 
+@dataclasses.dataclass
+class ExecutionResult:
+    data: Optional[Dict[str, Any]]
+    errors: Optional[List[GraphQLError]]
+
+
 class BaseSchema(Protocol):
     @abstractmethod
     async def execute(
@@ -16,6 +24,28 @@ class BaseSchema(Protocol):
         context_value: Optional[Any] = None,
         root_value: Optional[Any] = None,
         operation_name: Optional[str] = None,
+    ) -> ExecutionResult:
+        raise NotImplementedError
+
+    @abstractmethod
+    def execute_sync(
+        self,
+        query: str,
+        variable_values: Optional[Dict[str, Any]] = None,
+        context_value: Optional[Any] = None,
+        root_value: Optional[Any] = None,
+        operation_name: Optional[str] = None,
+    ) -> ExecutionResult:
+        raise NotImplementedError
+
+    @abstractmethod
+    async def subscribe(
+        self,
+        query: str,
+        variable_values: Optional[Dict[str, Any]] = None,
+        context_value: Optional[Any] = None,
+        root_value: Optional[Any] = None,
+        operation_name: Optional[str] = None,
     ):
         raise NotImplementedError
 
@@ -25,28 +55,6 @@ class BaseSchema(Protocol):
     ) -> Optional[Union[TypeDefinition, ScalarDefinition, EnumDefinition]]:
         raise NotImplementedError
 
-    @abstractmethod
-    def execute_sync(
-        self,
-        query: str,
-        variable_values: Optional[Dict[str, Any]] = None,
-        context_value: Optional[Any] = None,
-        root_value: Optional[Any] = None,
-        operation_name: Optional[str] = None,
-    ):
-        raise NotImplementedError
-
-    @abstractmethod
-    async def subscribe(
-        self,
-        query: str,
-        variable_values: Optional[Dict[str, Any]] = None,
-        context_value: Optional[Any] = None,
-        root_value: Optional[Any] = None,
-        operation_name: Optional[str] = None,
-    ):
-        raise NotImplementedError
-
     @abstractmethod
     def as_str(self) -> str:
         raise NotImplementedError
